summaryrefslogtreecommitdiff
path: root/keyboards/jj40/keymaps/oscillope/keymap.c
diff options
context:
space:
mode:
authorOscillope <jvrosenman@gmail.com>2018-06-12 17:50:48 -0400
committerDrashna Jaelre <drashna@live.com>2018-06-12 14:50:48 -0700
commit2e8e8337b9bf4967150cd51a144b30b0110df06d (patch)
tree703ad1423b2007f8415eddba747dff692f119242 /keyboards/jj40/keymaps/oscillope/keymap.c
parentd0e635aa1b99300cd1643e259385c23ad0d27e7c (diff)
Fix jj40 capslock and minor keymap updates (#3168)
* Adjust TAPPING_TERM to make accessing the nav layer easier * JJ40: Add RESET key to lower layer. * Disable all lock LEDs on "oscillope" keymap. I'm not 100% sure why yet, but attempting to turn on a lock LED on my v1 JJ40 PCB causes the PCB to become unresponsive. The easy fix is to just disable all of the lock LEDs, since I don't have any LEDs on my keyboard anyway. Many thanks to u/wanleg on Reddit for suggesting this fix: https://www.reddit.com/r/olkb/comments/8en8f1/strange_caps_lock_behavior/e06kcaf/
Diffstat (limited to 'keyboards/jj40/keymaps/oscillope/keymap.c')
-rw-r--r--keyboards/jj40/keymaps/oscillope/keymap.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/keyboards/jj40/keymaps/oscillope/keymap.c b/keyboards/jj40/keymaps/oscillope/keymap.c
index 710fa16f7a..49ceff864c 100644
--- a/keyboards/jj40/keymaps/oscillope/keymap.c
+++ b/keyboards/jj40/keymaps/oscillope/keymap.c
@@ -64,7 +64,7 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
* |------+------+------+------+------+-------------+------+------+------+------+------|
* | Ins | | | () | [] | {} | Left | Down | Up |Right | | |
* |------+------+------+------+------+------|------+------+------+------+------+------|
* |PrScr | Back | Fwd | | | | | | Mute | Vol- | Vol+ | |
* |------+------+------+------+------+------+------+------+------+------+------+------|
* | | | | | Lock | | | Prev | Stop | Play | Next |
* `-----------------------------------------------------------------------------------'
@@ -72,7 +72,7 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
[_LOWER] = KEYMAP( \
KC_F1, KC_F2, KC_F3, KC_F4, KC_F5, KC_F6, KC_F7, KC_F8, KC_F9, KC_F10, KC_F11, KC_F12, \
KC_INS, _______, _______, CC_PRN, CC_BRC, CC_CBR, KC_LEFT, KC_DOWN, KC_UP, KC_RGHT, _______, _______, \
- KC_PSCR, KC_WBAK, KC_WFWD, _______, _______, _______, _______, _______, KC_MUTE, KC_VOLD, KC_VOLU, _______, \
+ RESET, KC_WBAK, KC_WFWD, _______, _______, _______, _______, _______, KC_MUTE, KC_VOLD, KC_VOLU, _______, \
_______, _______, _______, _______, KC_LOCK, _______, _______, KC_MPRV, KC_MSTP, KC_MPLY, KC_MNXT \
),
@@ -64,7 +64,7 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
* | Ins | | | () | [] | {} | Left | Down | Up |Right | | |
* |------+------+------+------+------+------|------+------+------+------+------+------|
- * |PrScr | Back | Fwd | | | | | | Mute | Vol- | Vol+ | |
+ * |RESET | Back | Fwd | | | | | | Mute | Vol- | Vol+ | |
* |------+------+------+------+------+------+------+------+------+------+------+------|
* | | | | | Lock | | | Prev | Stop | Play | Next |